// pass tooltip to object
MovieClip.prototype.setToolTip = function( toolTip, handCursor )
{
	if( handCursor == undefined ) handCursor = false;
	this._theTooltip = new ToolTipClass( this, toolTip, handCursor);
}


// The tool tip class
function ToolTipClass(targetObject, tipText, handCursor){
	
	this.targetInstance = targetObject;
	this.displayText = tipText;
	this.handCursor = handCursor;
	//targetObject._theTooltip = this;
	
	this.hitsCounter = 0;
	// Initialise the class
	this.init();
	
}

ToolTipClass.prototype = new MovieClip();
//Object.registerClass("FTooltipLiteSymbol", ToolTipClass);

// Initialise the class
ToolTipClass.prototype.init = function() {
	
	// Setup default properties, if needed
	if (this.activeState == undefined) this.activeState = true;
	if (this.handCursor == undefined) this.handCursor = true;	
	if (this.displayText == undefined) this.displayText = "";
	
	// Define compulsory default properties, these can only be changed via ActionScript
	// after this code has already executed
	this.yOffset = 30;
	this.xOffset = 12;
	this.displayDelay = 300;
	this.text_color = 0x000000;
	this.bg_color = 0xFFFFE1;
	this.border_color = 0x000000;
	this.showInterval = 5*1000;

	// Setup the target symbol
	//this.targetInstance = this._parent[this._targetInstanceName];
	
	this.controller = this;
		
	// Setup mouse hooks
	this.targetOnRollOver = this.targetInstance.onRollOver;
	this.targetOnRollOut = this.targetInstance.onRollOut;
	this.targetOnReleaseOutside = this.targetInstance.onReleaseOutside;
	
	// Reassign event handlers from target clip to use our handler
	this.targetInstance.onRollOver = this.onRollOver;
	this.targetInstance.onRollOut = this.onRollOut;
	this.targetInstance.onReleaseOutside = this.onReleaseOutside;
	
	// Set up watches on onRollOver and onRollOut in case user overrides
	this.targetInstance.watch("onRollOver", this.ttROverReassign, this);
	this.targetInstance.watch("onRollOut", this.ttROutReassign, this);
	this.targetInstance.watch("onReleaseOutside", this.ttROutsideReassign, this);
	
	// Record pointer back to us in the targetInstance so we can scope events properly
	this.targetInstance.toolTipLite_mc = this;
	
	// Set up the hand cursor property
	this.targetInstance.useHandCursor = this.handCursor;	
}

//
// PRIVATE METHODS
//

// Method: display the tool tip
ToolTipClass.prototype.displayToolTip = function() {	
	if(this.displayText == undefined || this.displayText == "") return;
	
	this.setTooltip( this.displayText, this.displayDelay, this.text_color, this.bg_color, this.border_color);	
}

ToolTipClass.prototype.setDisplayText = function( str )
{ 
	this.displayText = str;
}

// function: remove a tool tip
ToolTipClass.prototype.removeToolTip = function() {
	
	this.unsetTooltip();
	
}

// This function is triggered if the user reassigns onRollOver.
// We need to make sure our onRollOver is persistant
ToolTipClass.prototype.ttROverReassign = function(prop, oldVal, newVal, thisVal) {
	
	// Setup mouse hook
	thisVal.targetOnRollOver = newVal;
	
	// Reassign event handlers from target clip to use our handler
	return (thisVal.onRollOver);
}

// This function is triggered if the user reassigns onRollOut. 
ToolTipClass.prototype.ttROutReassign = function(prop, oldVal, newVal, thisVal) {
	
	// Setup mouse hooks
	thisVal.targetOnRollOut = newVal;
	
	// Reassign event handlers from target clip to use our handler
	return (thisVal.onRollOut);
}

// This function is triggered if the user reassigns onRollOut. 
ToolTipClass.prototype.ttROutsideReassign = function(prop, oldVal, newVal, thisVal) {
	
	// Setup mouse hooks
	thisVal.targetOnReleaseOutside = newVal;
	
	// Reassign event handlers from target clip to use our handler
	return (thisVal.onReleaseOutside);
}


// Our onRollOver event
// We do what we need to do, then let the target clip do it's events
ToolTipClass.prototype.onRollOver = function() {
	
	// Call our toolTipLite_mc, after the user-defined delay elapses.
	this.toolTipLite_mc.displayToolTip();
	this.toolTipLite_mc.targetOnRollOver.call(this);
	
}

// Our onRollOut event.
ToolTipClass.prototype.onRollOut = function() {	
	this.toolTipLite_mc.targetOnRollOut.call(this);	
	this.toolTipLite_mc.removeToolTip.call(this.toolTipLite_mc);	
}

// Our onReleaseOutside event.
ToolTipClass.prototype.onReleaseOutside = function() {
	
	this.toolTipLite_mc.targetOnReleaseOutside.call(this);	
	this.toolTipLite_mc.removeToolTip.call(this.toolTipLite_mc);
	
}

ToolTipClass.prototype.setTooltip = function(theText, timer, text_color, bg_color, border_color)
{
   this.hitsCounter++;
   
   //if( Math.ceil(this.hitsCounter / 5) % 2 == 0 ) return;
   
   if (timer == undefined)
   {
      timer = 500;
   }
   var addMsg = function (theMsg, col, bg_color, border_color, level)
   {	 
      var x = _root._xmouse + level.xOffset;
      var y = _root._ymouse + level.yOffset;      
      var f = new TextFormat();
      f.font = "Verdana";
      f.size = 11;
      f.color = col != undefined ? col : 0x000000;
      _level0.tooltip.removeTextField();
      clearInterval(level.u_t);
      _level0.createTextField('tooltip', 123456, x, y, 150, 20);
      with (_level0.tooltip)
      {
         setNewTextFormat(f);
         text = theMsg;
         selectable = false;
         autoSize = true;
         background = true;
         border = true;
         borderColor = border_color != undefined ? border_color : 0x000000;
         backgroundColor = bg_color != undefined ? bg_color : 0xFFFFE1;
         _y -= _height;
      }
      clearInterval(level.q_t);
      level.u_t = setInterval(level,"unsetTooltip", level.showInterval);
   };
   
   this.q_t = setInterval(addMsg, timer, theText, text_color, bg_color, border_color, this);
};


ToolTipClass.prototype.unsetTooltip = function()
{
   _level0.tooltip.removeTextField();
   clearInterval(this.q_t);
   clearInterval(this.u_t);	
};
